@@ -34,10 +34,11 @@ from multiprocessing import Process, Pipe
 from .Watcher import *
 import psutil
 import warnings
+from .DataStruct import *
 
 
 def _watcher_process(main_pid, host, port, conn):
-    device = Device(host=host, port=port, main=False)
+    device = Device(host=host, port=port, _main=False)
     WatchWorker(device, conn, main_pid).run()
 
 
@@ -70,6 +71,9 @@ def _start_web_driver_daemon(wb_pid):
 
 
 class Device(Events):
+    """
+    SyberOS设备类，继承自Events基类，负责驱动设备模拟事件与获取布局信息
+    """
     con = Connection()
     __osVersion = ""
     __serialNumber = ""
@@ -88,16 +92,9 @@ class Device(Events):
     __width = 0
     __height = 0
     __syslog_tid = None
-    """
-    control_host_type:
-        0: anywhere
-        1: windows amd64
-        2: linux x86_64
-        3: darwin x86_64
-    """
-    control_host_type = 0
+    control_host_type = Controller.ANYWHERE
 
-    def __init__(self, host="192.168.100.100", port=10008, main=True):
+    def __init__(self, host="192.168.100.100", port=10008, _main=True):
         super().__init__(d=self)
         warnings.simplefilter('ignore', ResourceWarning)
         self.con.host = host
@@ -107,9 +104,9 @@ class Device(Events):
         self.__serialNumber = str(self.con.get(path="getSerialNumber").read(), 'utf-8')
         self.__osVersion = str(self.con.get(path="getOsVersion").read(), 'utf-8')
         self.__set_display_size()
-        if main:
+        if _main:
             self.__check_platform()
-            if self.control_host_type != 0:
+            if self.control_host_type != Controller.ANYWHERE:
                 _start_web_driver_daemon(self.__wb_process.pid)
                 _start_watcher(host, port, self.__watcher_conn)
             syslog_thread = threading.Thread(target=self.__logger)
@@ -123,13 +120,13 @@ class Device(Events):
         p = platform.system()
         m = platform.machine()
         if p == "Windows" and m == "AMD64":
-            self.control_host_type = 1
+            self.control_host_type = Controller.WINDOWS_AMD64
             self.__init_webdriver("win32_x86_64_phantomjs", "libsimulation-rendering.dll")
         elif p == "Linux" and m == "x86_64":
-            self.control_host_type = 2
+            self.control_host_type = Controller.LINUX_X86_64
             self.__init_webdriver("linux_x86_64_phantomjs", "libsimulation-rendering.so")
         elif p == "Darwin" and m == "x86_64":
-            self.control_host_type = 3
+            self.control_host_type = Controller.DARWIN_X86_64
             self.__init_webdriver("darwin_x86_64_phantomjs", "libsimulation-rendering.dylib")
 
     def __init_webdriver(self, p_name, l_name):
@@ -174,6 +171,12 @@ class Device(Events):
                 syslog_file.flush()
 
     def set_syslog_output(self, is_enable: bool, keyword: str = "") -> None:
+        """
+        设置设备log输出开关
+        :param is_enable:
+        :param keyword:
+        :return:
+        """
         self.__syslog_output_keyword = keyword
         self.__syslog_output = is_enable
 
