@@ -35,7 +35,7 @@ html_string_3 = "px;clip:rect(auto,auto,auto,auto);\">"
 html_string_4 = "</div></body></html>"
 
 
-class WorkerThread(threading.Thread):
+class _WorkerThread(threading.Thread):
 
     result = None
 
@@ -273,7 +273,7 @@ class Item:
         th_index = 0
         th_list = {}
         for node in nodes:
-            th = WorkerThread(func=self.__draw_item, args=(node, fs, ))
+            th = _WorkerThread(func=self.__draw_item, args=(node, fs, ))
             th_list[th_index] = th
             th.setDaemon(True)
             th_index += 1
